Range-v3: ranges::v3::action::unique_fn::ConceptImpl Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::action::unique_fn::ConceptImpl Struct Reference

## Public Member Functions
template<typename Rng , typename C = equal_to, typename P = ident, typename I = iterator_t<Rng>, typename S = sentinel_t<Rng>>
auto | requires_ () -> decltype(concepts::valid_expr(concepts::model_of< concepts::ForwardRange, Rng >(), concepts::model_of< concepts::ErasableRange, Rng, I, S >(), concepts::is_true(Sortable< I, C, P >())))